@@ -22,7 +22,7 @@ Readonly::Scalar my $LINE_SIZE => 79;
 Readonly::Scalar my $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Resets internal variables.
 sub reset {
@@ -601,12 +601,12 @@ __END__
 
 =item * C<line_size>
 
- TODO
+ Line size.
  Default value is 79.
 
 =item * C<next_indent>
 
- TODO
+ Value of indent, which are added to begin of line.
  Default value is "  ".
 
 =item * C<no_simple>
@@ -640,14 +640,14 @@ __END__
  Must be a GLOB.
  Default is undef.
 
-=item * C<output_separator>
+=item * C<output_sep>
 
- TODO
+ Output separator.
  Default value is newline (\n).
 
 =item * C<preserved>
 
- TODO
+ List of elements, which content will be preserved.
  Default value is reference to blank array.
 
 =item * C<raw_callback>
@@ -659,12 +659,12 @@ __END__
 
 =item * C<skip_bad_tags>
 
- TODO
+ Skip bad tags.
  Default value is 0.
 
 =item * C<strict_instruction>
 
- TODO
+ Strict instruction.
  Default value is 1.
 
 =back
@@ -756,21 +756,9 @@ Structure oriented SGML/XML/HTML/etc. elements manipulation.
 
 Base class for Tags::Output::*.
 
-=item L<Tags::Output::LibXML>
+=item L<Task::Tags>
 
-Printing 'Tags' structure by LibXML library.
-
-=item L<Tags::Output::PYX>
-
-PYX class for line oriented output for 'Tags'.
-
-=item L<Tags::Output::Raw>
-
-Raw printing 'Tags' structure to tags code.
-
-=item L<Tags::Utils>
-
-Utils module for Tags.
+Install the Tags modules.
 
 =back
 
@@ -785,6 +773,6 @@ Michal Špaček L<skim@cpan.org>
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
